Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(704)

Unified Diff: components/sync/model/model_type_sync_bridge.h

Issue 2458013002: [Sync] Rename ModelTypeService to ModelTypeSyncBridge. (Closed)
Patch Set: s/SetBridgeError/ErrorOnNextCall Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/model/model_type_sync_bridge.h
diff --git a/components/sync/model/model_type_service.h b/components/sync/model/model_type_sync_bridge.h
similarity index 91%
rename from components/sync/model/model_type_service.h
rename to components/sync/model/model_type_sync_bridge.h
index 3d39d5b16687db84b56f7ea3e3bf599baf34813c..dd9d5f6db2baad3511afe9e1418995bdb2822dd7 100644
--- a/components/sync/model/model_type_service.h
+++ b/components/sync/model/model_type_sync_bridge.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_SYNC_MODEL_MODEL_TYPE_SERVICE_H_
-#define COMPONENTS_SYNC_MODEL_MODEL_TYPE_SERVICE_H_
+#ifndef COMPONENTS_SYNC_MODEL_MODEL_TYPE_SYNC_BRIDGE_H_
+#define COMPONENTS_SYNC_MODEL_MODEL_TYPE_SYNC_BRIDGE_H_
#include <memory>
#include <string>
@@ -27,20 +27,20 @@ class MetadataChangeList;
// Interface implemented by model types to receive updates from sync via the
// SharedModelTypeProcessor. Provides a way for sync to update the data and
// metadata for entities, as well as the model type state.
-class ModelTypeService : public base::SupportsWeakPtr<ModelTypeService> {
+class ModelTypeSyncBridge : public base::SupportsWeakPtr<ModelTypeSyncBridge> {
public:
typedef base::Callback<void(SyncError, std::unique_ptr<DataBatch>)>
DataCallback;
typedef std::vector<std::string> StorageKeyList;
typedef base::Callback<std::unique_ptr<ModelTypeChangeProcessor>(
ModelType type,
- ModelTypeService* service)>
+ ModelTypeSyncBridge* bridge)>
ChangeProcessorFactory;
- ModelTypeService(const ChangeProcessorFactory& change_processor_factory,
- ModelType type);
+ ModelTypeSyncBridge(const ChangeProcessorFactory& change_processor_factory,
+ ModelType type);
- virtual ~ModelTypeService();
+ virtual ~ModelTypeSyncBridge();
// Creates an object used to communicate changes in the sync metadata to the
// model type store.
@@ -51,7 +51,7 @@ class ModelTypeService : public base::SupportsWeakPtr<ModelTypeService> {
// sync metadata. Best effort should be made to match local and sync data. The
// keys in the |entity_data_map| will have been created via GetClientTag(...),
// and if a local and sync data should match/merge but disagree on tags, the
// service should use the sync data's tag. Any local pieces of data that are
// not present in sync should immediately be Put(...) to the processor before
// returning. The same MetadataChangeList that was passed into this function
// can be passed to Put(...) calls. Delete(...) can also be called but should
@@ -125,4 +125,4 @@ class ModelTypeService : public base::SupportsWeakPtr<ModelTypeService> {
} // namespace syncer
-#endif // COMPONENTS_SYNC_MODEL_MODEL_TYPE_SERVICE_H_
+#endif // COMPONENTS_SYNC_MODEL_MODEL_TYPE_SYNC_BRIDGE_H_
« no previous file with comments | « components/sync/model/model_type_service_unittest.cc ('k') | components/sync/model/model_type_sync_bridge.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -51,7 +51,7 @@ class ModelTypeService : public base::SupportsWeakPtr<ModelTypeService> {
// keys in the |entity_data_map| will have been created via GetClientTag(...),
// and if a local and sync data should match/merge but disagree on tags, the
- // service should use the sync data's tag. Any local pieces of data that are
+ // bridge should use the sync data's tag. Any local pieces of data that are
// not present in sync should immediately be Put(...) to the processor before
// returning. The same MetadataChangeList that was passed into this function
This is Rietveld 408576698